@@ -61,8 +61,8 @@
 #' @param use.initial.values If \code{TRUE} and \code{model} is of class
 #' \code{"ets"}, then the initial values in the model are also not
 #' re-estimated.
-#' @param na.action A function which indicates what should happen when the data 
-#' contains NA values. By default, the largest contiguous portion of the 
+#' @param na.action A function which indicates what should happen when the data
+#' contains NA values. By default, the largest contiguous portion of the
 #' time-series will be used.
 #' @param ... Other undocumented arguments.
 #' @inheritParams forecast
@@ -413,11 +413,14 @@ ets <- function(y, model="ZZZ", damped=NULL,
           if (!data.positive && errortype[i] == "M") {
             next
           }
-          fit <- etsmodel(
+          fit <- try(etsmodel(
             y, errortype[i], trendtype[j], seasontype[k], damped[l], alpha, beta, gamma, phi,
             lower = lower, upper = upper, opt.crit = opt.crit, nmse = nmse, bounds = bounds, ...
-          )
-          fit.ic <- switch(ic, aic = fit$aic, bic = fit$bic, aicc = fit$aicc)
+          ), silent=TRUE)
+          if(is.element("try-error", class(fit)))
+            fit.ic <- Inf
+          else
+            fit.ic <- switch(ic, aic = fit$aic, bic = fit$bic, aicc = fit$aicc)
           if (!is.na(fit.ic)) {
             if (fit.ic < best.ic) {
               model <- fit
@@ -446,7 +449,7 @@ ets <- function(y, model="ZZZ", damped=NULL,
   model$sigma2 <- sum(model$residuals^2, na.rm = TRUE) / (ny - np)
   model$x <- orig.y
   if (!is.null(lambda)) {
-    model$fitted <- InvBoxCox(model$fitted, lambda, biasadj, var(model$residuals))
+    model$fitted <- InvBoxCox(model$fitted, lambda, biasadj, model$sigma2)
     attr(lambda, "biasadj") <- biasadj
   }
 
@@ -937,9 +940,9 @@ initstate <- function(y, trendtype, seasontype) {
       fouriery <- fourier(y, 1)
       fit <- tslm(y ~ trend + fouriery)
       if (seasontype == "A") {
-        y.d <- list(seasonal = y - fit$coef[1] - fit$coef[2] * (1:n))
+        y.d <- list(seasonal = y - fit$coefficients[1] - fit$coefficients[2] * (1:n))
       } else { # seasontype=="M". Biased method, but we only need a starting point
-        y.d <- list(seasonal = y / (fit$coef[1] + fit$coef[2] * (1:n)))
+        y.d <- list(seasonal = y / (fit$coefficients[1] + fit$coefficients[2] * (1:n)))
       }
     }
     else { # n is large enough to do a decomposition
@@ -976,8 +979,8 @@ initstate <- function(y, trendtype, seasontype) {
   {
     fit <- lsfit(1:maxn, y.sa[1:maxn])
     if (trendtype == "A") {
-      l0 <- fit$coef[1]
-      b0 <- fit$coef[2]
+      l0 <- fit$coefficients[1]
+      b0 <- fit$coefficients[2]
       # If error type is "M", then we don't want l0+b0=0.
       # So perturb just in case.
       if (abs(l0 + b0) < 1e-8) {
@@ -987,11 +990,11 @@ initstate <- function(y, trendtype, seasontype) {
     }
     else # if(trendtype=="M")
     {
-      l0 <- fit$coef[1] + fit$coef[2] # First fitted value
+      l0 <- fit$coefficients[1] + fit$coefficients[2] # First fitted value
       if (abs(l0) < 1e-8) {
         l0 <- 1e-7
       }
-      b0 <- (fit$coef[1] + 2 * fit$coef[2]) / l0 # Ratio of first two fitted values
+      b0 <- (fit$coefficients[1] + 2 * fit$coefficients[2]) / l0 # Ratio of first two fitted values
       l0 <- l0 / b0 # First fitted value divided by b0
       if (abs(b0) > 1e10) { # Avoid infinite slopes
         b0 <- sign(b0) * 1e10
